__all__ = ["__version__", "DEFAULT_OFFICIAL_BUCKET_BASE"]
__version__ = "0.1.26"

# Default official bucket base (commands live under "cmds/")
# This value is used to initialize ~/.nuro/config/config.json when missing.
DEFAULT_OFFICIAL_BUCKET_BASE = "https://raw.githubusercontent.com/nor-void/nuro/main"
